==> app-0.15.0.tar.gz: app-0.15.0/README.md <==
Phundament
==========

**Version 3-0.15.0**


What is Phundament?
-------------------

Phundament is a solid, highly customizable universal application foundation built with [composer](http://getcomposer.org) 
upon [Yii Framework](http://yiiframework.com). 

It's goal is the seamless integration of Yii extensions and libraries bundled in composer packages packages. 
[Read on…](https://github.com/phundament/app/wiki/Phundament)



Quick-Start
-----------

1. [Download](https://github.com/phundament/app/tags) & extract
2. Enter the app root folder and start the installation process
```
php composer.phar install
```
3. Open `phundament-app/www/index.php` in your browser
4. [Manage your application](https://github.com/phundament/app/wiki/Content-Management)

*Note: if you want to install Phundament 3 with a MySQL database, you have to update your config first, see the [Setup](https://github.com/phundament/app/wiki/Setup) section in our wiki.*
*You may add the `--dev` and `--prefer-source` options on development systems.*

Documentation
-------------

 * [The Definitive Guide to Phundament](https://github.com/phundament/app/wiki)

Demo
----

 * Try a test-drive at the [Demo Page](http://demo.phundament.com/3.0-dev)
   * Login with `editor` / `editor` or register by e-mail.


Resources
---------

### Fundamentals
 *  [Documentation](https://github.com/phundament/app/wiki/)
 *  [FAQ / Troubleshooting](https://github.com/phundament/app/wiki/FAQ)
 *  [Support](https://github.com/phundament/app/wiki/Support)
 *  [Report a bug](https://github.com/phundament/app/issues)
 *  Composer Repository [packages.phundament.com](http://packages.phundament.com)

### Information
 *  [CHANGELOG](https://github.com/phundament/app/blob/0.15.0/CHANGELOG.md)
 *  [Packages in Phundament 0.15.0](https://github.com/phundament/app/blob/0.15.0/composer.lock)
 *  [License](https://github.com/phundament/app/blob/0.15.0/LICENSE) BSD

### Links
 *  [Phundament Website](http://phundament.com)
 *  [View at Yii Extensions](http://www.yiiframework.com/extension/phundament/)
 *  [Fork on github](https://github.com/phundament/app)
 *  [Downloads](https://github.com/phundament/app/tags)
 *  [Company Website](http://herzogkommunikation.de)
 *  [Demo Website](http://demo.phundament.com/3.0-dev/)

### Social Networks
 *  [Twitter](http://twitter.com/#!/phundament)
 *  [Facebook](http://www.facebook.com/phundament)
 *  [Google+](https://plus.google.com/114873431066202526630)

### Contact
 *  phundament@usrbin.de

==> app-0.17.0.tar.gz: app-0.17.0/README.md <==
Phundament
==========

**Version 3-0.17.0-dev**


What is Phundament?
-------------------

Phundament is a solid, highly customizable universal application foundation built with [composer](http://getcomposer.org) 
upon [Yii Framework](http://yiiframework.com). 

It's goal is the seamless integration of Yii extensions and libraries bundled in composer packages packages. 
[Read on…](https://github.com/phundament/app/wiki/Phundament)



Quick-Start
-----------

### Step 1
   A) If you have composer already installed
   
```
composer.phar create-project phundament/app
```   
   
   B) [Download](https://github.com/phundament/app/tags), extract, enter the app root folder
      and start the installation process with
```
php composer.phar install
```
### Step 2

Open `phundament-app/www/index.php` in your browser

### Step 3

[Manage your application](https://github.com/phundament/app/wiki/Content-Management)

*Note: if you want to install Phundament 3 with a MySQL database, you have to update your config first, see the [Setup](https://github.com/phundament/app/wiki/Setup) section in our wiki.*
*You may add the `--dev` and `--prefer-source` options on development systems.*

Documentation
-------------

 * [The Definitive Guide to Phundament](https://github.com/phundament/app/wiki)

Demo
----

 * Try a test-drive at the [Demo Page](http://demo.phundament.com/3.0-dev)
   * Login with `editor` / `editor` or register by e-mail.


Resources
---------

### Fundamentals
 *  [Documentation](https://github.com/phundament/app/wiki/)
 *  [API Class Reference](http://docs.phundament.com/3.0)
 *  [FAQ / Troubleshooting](https://github.com/phundament/app/wiki/FAQ)
 *  [Support](https://github.com/phundament/app/wiki/Support)
 *  [Report a bug](https://github.com/phundament/app/issues)
 *  Composer Repository [packages.phundament.com](http://packages.phundament.com)

### Information
 *  [CHANGELOG](https://github.com/phundament/app/blob/master/CHANGELOG.md)
 *  [License](https://github.com/phundament/app/blob/master/LICENSE) BSD

### Links
 *  [Phundament Website](http://phundament.com)
 *  [View at Yii Extensions](http://www.yiiframework.com/extension/phundament/)
 *  [View at packagist.org](https://packagist.org/packages/phundament/app)
 *  [Fork on github](https://github.com/phundament/app)
 *  [Downloads](https://github.com/phundament/app/tags)
 *  [Company Website](http://herzogkommunikation.de)
 *  [Demo Website](http://demo.phundament.com/3.0-dev/)

### Social Networks
 *  [Twitter](http://twitter.com/#!/phundament)
 *  [Facebook](http://www.facebook.com/phundament)
 *  [Google+](https://plus.google.com/114873431066202526630)

### Contact
 *  phundament@usrbin.de
